\name{dclike.panel}
\alias{dclike.panel}
\title{
A function to compute the value of the log likelihood for a given set of
panel data and a given value of the parameters.
}
\description{
A fortran program is called to compute the value of the log likelihood.
}
\usage{
dclike.panel(indata, ainv, amat, evalues, ncov, nstage)
}
\arguments{
\item{indata}{
indata is a list with one entry for each individual. Each entry is a structure
with the components:
time: the inspection times for that individual
stage: the stage the individual is in at each inspection times
cov: the value of the covariate for that individual at the inspection time
len: the number of inspections for that individual
}
\item{ainv}{
The inverse of the intensity matrix.
}
\item{amat}{ The intensity matrix.}
\item{evalues}{The eigenvalues.}
\item{ncov}{
The number of levels the covariate comes at.
}
\item{nstage}{
nstage is the number of stages in the Markov model.
}}
\value{
The value of the log likelihood is returned.
}
\section{Side Effects}{
There are no known side effects.
}
\seealso{
panel, eddcmp
}
\examples{
}
\keyword{utilities}

\eof
\name{eddcmp}
\alias{eddcmp}
\title{Eigenvalue--eigenvector decomposition.}
\description{
A function that produces an eigenvalue eigenvector decomposition of a
transition intensity matrix for a Markov chain in double precision.
}
\usage{
eddcmp(inmat)
}
\arguments{
\item{inmat}{
inmat is any square matrix describing the markov chain
}}
\value{
A list with named components is returned. 

\item{evectors}{
 a matrix containing the left eigenvectors 
}
\item{evalues}{
a vector containing the eigenvalues 
}
\item{im.evalues}{
a vector which contains the imaginary components of the eigenvalues
if there are any (otherwise this is the zero vector).
}}
\examples{
}
\section{COMMENTS}{
  The matrix inmat is decomposed as evectors \%*\% diag(evalues) \%*\% solve(evectors).
For most matrices of interest the eigenvalues will all be real so the imaginary
part is commonly ignored.
The eigenvalues are ordered from smallest to largest.
}
\keyword{array}
\eof
\name{kldata}
\alias{kldata}
\non_function{}
\title{The data set given in Kalbfleisch and Lawless (1985). }
\usage{data(kldata)}

}
\source{
  Kalbfleisch, J.D. and Lawless, J.F. `The analysis
of panel data under a Markov assumption', {\em Journal of the
American Statistical Association}, {\bf 80}, 863-871, (1985).
}
\description{
In Section 6 of Kalbfleisch and Lawless (1985) some data simulated from
a three-state Markov model is given.
They started 15 individuals in each of States 1 and 2 for each of four
groups.Individuals were followed for 5 transitions at equidistant time
intervals. 
  }
\examples{
data(kldata)
##see the user's manual for explicit examples
}
\keyword{datasets}
\eof
\name{panel}
\alias{panel}
\title{
A function to compute the maximum likelihood estimates of the transition
parameters from panel data.
}
\description{
The algorithm is discussed in Kalbfleisch and Lawless (1985) and
further in Gentleman (1994).
}
\usage{
panel(indata, qmatf, gamma, qderivf, npar, nstage, ncov, verbose = F,
        tol = 0.001)
}
\arguments{
\item{indata}{
indata is a list with one element for each individual. Each element of
indata is a structure with 4 components. 
time: a vector containing the inspection times
stage: a vector containing the state of the individual at the 
corresponding inspection time 
cov: a vector containing the covariate values at the inspection times
len: the number of inspections on 
that individual
}
\item{npar}{
npar is the number of parameters that are to be estimated
}
\item{nstage}{
nstage is the number of stages/states in the model
}
\item{ncov}{
ncov is the number of levels the covariate comes at
}
\item{qmatf}{
qmatf is a function that accepts as input gamma (the parameters)
and returns an array (ncov x nstage x nstage) with the ncov transition
intensity matrices.
}
\item{gamma}{
gamma is a vector (npar long) of estimates of the transition parameters.
}
\item{qderivf}{
qderivf is a function that takes gamma as an argument and returns an
array (npar x ncov x nstage x nstage) with the derivatives of the transition
intensity matrices with respect to each of the parameters.
}
\item{verbose}{
If verbose is set to TRUE then on each iteration the current estimate of theta
and the current value of the score function are printed out.
}
\item{tol}{ The tolerance used to determine convergence.
}}
\value{
panel returns a list with the parameter estimates, their standard errors
and the log likelihood on convergence.
}
\section{Side Effects}{
There are no known side effects.
}
\references{
Kalbfleisch J. D. and Lawless J. F. "The Analysis of Panel Data Under
a Markov Assumption", JASA (1985), p. 863.
Gentleman R. (1994). The Use of Covariate Information in Multi-state
Markov Models. Technical Report 13, Department of Statistics, University
of Auckland.
}
\seealso{
eddcmp, dclike.panel
}
\examples{
#See the accompanying document "A Users Guide to panel" for
#examples and code segments.
}
\keyword{models}
\eof
